API Reference
=============

.. automodule:: metasynth
   :members:
   :undoc-members:
   :show-inheritance:


Subpackages
-----------

.. toctree::
   :maxdepth: 1

   metasynth.distribution
   metasynth.schema

Submodules
----------

metasynth.dataset module
------------------------

.. automodule:: metasynth.dataset
   :members:
   :undoc-members:
   :show-inheritance:

metasynth.provider module
-------------------------

.. automodule:: metasynth.provider
   :members:
   :undoc-members:
   :show-inheritance:

metasynth.var module
--------------------

.. automodule:: metasynth.var
   :members:
   :undoc-members:
   :show-inheritance:

metasynth.testutils module
--------------------------

.. automodule:: metasynth.testutils
   :members:
   :undoc-members:
   :show-inheritance:

metasynth.validation module
---------------------------

.. automodule:: metasynth.validation
   :members:
   :undoc-members:
   :show-inheritance:

metasynth.privacy module
------------------------

.. automodule:: metasynth.privacy
   :members:
   :undoc-members:
   :show-inheritance:
